@@ -19,7 +19,7 @@ options(useFancyQuotes=FALSE)
 
 
 ###################################################
-### code chunk number 3: datasets.Rnw:213-231
+### code chunk number 3: datasets.Rnw:217-235
 ###################################################
 opa <- par()
 ## How to set all margins to zero and eliminate all outer spaces
@@ -42,13 +42,13 @@ setmargins <- function(...) {
 
 
 ###################################################
-### code chunk number 4: datasets.Rnw:240-241 (eval = FALSE)
+### code chunk number 4: datasets.Rnw:244-245 (eval = FALSE)
 ###################################################
 ## plot(amacrine)
 
 
 ###################################################
-### code chunk number 5: datasets.Rnw:243-245
+### code chunk number 5: datasets.Rnw:247-249
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 setmargins(0,1,2,0)
@@ -56,13 +56,13 @@ plot(amacrine)
 
 
 ###################################################
-### code chunk number 6: datasets.Rnw:254-255 (eval = FALSE)
+### code chunk number 6: datasets.Rnw:258-259 (eval = FALSE)
 ###################################################
 ## plot(anemones, markscale=1)
 
 
 ###################################################
-### code chunk number 7: datasets.Rnw:257-259
+### code chunk number 7: datasets.Rnw:261-263
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 setmargins(0,0,2,0)
@@ -70,13 +70,13 @@ plot(anemones, markscale=1)
 
 
 ###################################################
-### code chunk number 8: datasets.Rnw:272-273 (eval = FALSE)
+### code chunk number 8: datasets.Rnw:276-277 (eval = FALSE)
 ###################################################
 ## ants.extra$plotit()
 
 
 ###################################################
-### code chunk number 9: datasets.Rnw:275-277
+### code chunk number 9: datasets.Rnw:279-281
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 setmargins(0,0,1,0)
@@ -84,21 +84,21 @@ ants.extra$plotit()
 
 
 ###################################################
-### code chunk number 10: datasets.Rnw:285-286
+### code chunk number 10: datasets.Rnw:289-290
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(austates)
 
 
 ###################################################
-### code chunk number 11: datasets.Rnw:296-298 (eval = FALSE)
+### code chunk number 11: datasets.Rnw:300-302 (eval = FALSE)
 ###################################################
 ## plot(bdspots, equal.scales=TRUE, pch="+", 
 ##      panel.args=function(i)list(cex=c(0.15, 0.2, 0.7)[i]))
 
 
 ###################################################
-### code chunk number 12: datasets.Rnw:300-304
+### code chunk number 12: datasets.Rnw:304-308
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 zeromargins()
@@ -108,14 +108,14 @@ plot(bdspots, equal.scales=TRUE, pch="+", main="",
 
 
 ###################################################
-### code chunk number 13: datasets.Rnw:314-316 (eval = FALSE)
+### code chunk number 13: datasets.Rnw:318-320 (eval = FALSE)
 ###################################################
 ## plot(bei.extra$elev, main="Beilschmiedia")
 ## plot(bei, add=TRUE, pch=16, cex=0.3)
 
 
 ###################################################
-### code chunk number 14: datasets.Rnw:318-321
+### code chunk number 14: datasets.Rnw:322-325
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 setmargins(0,0,2,0)
@@ -124,61 +124,59 @@ plot(bei, add=TRUE, pch=16, cex=0.3)
 
 
 ###################################################
-### code chunk number 15: datasets.Rnw:324-330
+### code chunk number 15: datasets.Rnw:331-337 (eval = FALSE)
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
-M <- persp(bei.extra$elev, 
-           theta=-45, phi=18, expand=7,
-           border=NA, apron=TRUE, shade=0.3, 
-           box=FALSE, visible=TRUE,
-           main="")
-perspPoints(bei, Z=bei.extra$elev, M=M, pch=16, cex=0.3)
+## M <- persp(bei.extra$elev, 
+##            theta=-45, phi=18, expand=7,
+##            border=NA, apron=TRUE, shade=0.3, 
+##            box=FALSE, visible=TRUE,
+##            main="")
+## perspPoints(bei, Z=bei.extra$elev, M=M, pch=16, cex=0.3)
 
 
 ###################################################
-### code chunk number 16: datasets.Rnw:339-340
+### code chunk number 16: datasets.Rnw:346-347
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(betacells)
 
 
 ###################################################
-### code chunk number 17: datasets.Rnw:345-346
+### code chunk number 17: datasets.Rnw:352-353
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(bramblecanes, cols=1:3)
 
 
 ###################################################
-### code chunk number 18: datasets.Rnw:349-350
+### code chunk number 18: datasets.Rnw:358-359 (eval = FALSE)
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
-plot(split(bramblecanes))
+## plot(split(bramblecanes))
 
 
 ###################################################
-### code chunk number 19: datasets.Rnw:360-361
+### code chunk number 19: datasets.Rnw:369-370
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(bronzefilter,markscale=2)
 
 
 ###################################################
-### code chunk number 20: datasets.Rnw:370-371
+### code chunk number 20: datasets.Rnw:379-380
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(cells)
 
 
 ###################################################
-### code chunk number 21: datasets.Rnw:379-380
+### code chunk number 21: datasets.Rnw:388-389
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(cetaceans.extra$patterns, main="Cetaceans data", cols=1:5, hsep=1)
 
 
 ###################################################
-### code chunk number 22: datasets.Rnw:389-392
+### code chunk number 22: datasets.Rnw:398-401
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(chicago, main="Chicago Crimes", col="grey",
@@ -187,14 +185,14 @@ plot(chicago, main="Chicago Crimes", col="grey",
 
 
 ###################################################
-### code chunk number 23: datasets.Rnw:402-403
+### code chunk number 23: datasets.Rnw:411-412
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 chorley.extra$plotit()
 
 
 ###################################################
-### code chunk number 24: datasets.Rnw:419-421
+### code chunk number 24: datasets.Rnw:428-430
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(clmfires, which.marks="cause", cols=2:5, cex=0.25,
@@ -202,14 +200,21 @@ plot(clmfires, which.marks="cause", cols=2:5, cex=0.25,
 
 
 ###################################################
-### code chunk number 25: datasets.Rnw:431-432
+### code chunk number 25: datasets.Rnw:440-441
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot(clmfires.extra$clmcov200, main="Covariates for forest fires")
+plot(clmfires.extra$clmcov100$elevation, main="Elevation")
 
 
 ###################################################
-### code chunk number 26: datasets.Rnw:443-445
+### code chunk number 26: datasets.Rnw:452-453
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+plot(concrete,chars="+",cols="blue",col="yellow")
+
+
+###################################################
+### code chunk number 27: datasets.Rnw:464-466
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(copper$Points, main="Copper")
@@ -217,7 +222,7 @@ plot(copper$Lines, add=TRUE)
 
 
 ###################################################
-### code chunk number 27: datasets.Rnw:452-454
+### code chunk number 28: datasets.Rnw:473-475
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(demohyper, quote({ plot(Image, main=""); plot(Points, add=TRUE) }),
@@ -225,28 +230,28 @@ plot(demohyper, quote({ plot(Image, main=""); plot(Points, add=TRUE) }),
 
 
 ###################################################
-### code chunk number 28: datasets.Rnw:461-462
+### code chunk number 29: datasets.Rnw:482-483
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(demopat)
 
 
 ###################################################
-### code chunk number 29: datasets.Rnw:476-477
+### code chunk number 30: datasets.Rnw:497-498
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(dendrite, leg.side="bottom", main="", cex=0.75, cols=2:4)
 
 
 ###################################################
-### code chunk number 30: datasets.Rnw:485-486
+### code chunk number 31: datasets.Rnw:506-507
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(finpines, main="Finnish pines")
 
 
 ###################################################
-### code chunk number 31: datasets.Rnw:499-503
+### code chunk number 32: datasets.Rnw:520-524
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 wildM1 <- with(flu, virustype == "wt" & stain == "M2-M1")
@@ -256,83 +261,88 @@ plot(flu[wildM1, 1, drop=TRUE],
 
 
 ###################################################
-### code chunk number 32: datasets.Rnw:511-512
+### code chunk number 33: datasets.Rnw:532-533
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(gordon, main="People in Gordon Square", pch=16)
 
 
 ###################################################
-### code chunk number 33: datasets.Rnw:527-528
+### code chunk number 34: datasets.Rnw:548-549
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(gorillas, which.marks=1, chars=c(1,3), cols=2:3, main="Gorilla nest sites")
 
 
 ###################################################
-### code chunk number 34: datasets.Rnw:532-533 (eval = FALSE)
+### code chunk number 35: datasets.Rnw:553-554 (eval = FALSE)
 ###################################################
 ## system.file("rawdata/gorillas/vegetation.asc", package="spatstat")
 
 
 ###################################################
-### code chunk number 35: datasets.Rnw:542-543
+### code chunk number 36: datasets.Rnw:563-564
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(hamster, cols=c(2,4))
 
 
 ###################################################
-### code chunk number 36: datasets.Rnw:553-554
+### code chunk number 37: datasets.Rnw:574-575
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot(heather)
+plot(heather$coarse)
 
 
 ###################################################
-### code chunk number 37: datasets.Rnw:564-565
+### code chunk number 38: datasets.Rnw:579-580 (eval = FALSE)
+###################################################
+## plot(heather)
+
+
+###################################################
+### code chunk number 39: datasets.Rnw:590-591
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(humberside)
 
 
 ###################################################
-### code chunk number 38: datasets.Rnw:577-578
+### code chunk number 40: datasets.Rnw:603-604
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(hyytiala, cols=2:5)
 
 
 ###################################################
-### code chunk number 39: datasets.Rnw:587-588
+### code chunk number 41: datasets.Rnw:613-614
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(japanesepines)
 
 
 ###################################################
-### code chunk number 40: datasets.Rnw:597-598
+### code chunk number 42: datasets.Rnw:623-624
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(lansing)
 
 
 ###################################################
-### code chunk number 41: datasets.Rnw:601-602
+### code chunk number 43: datasets.Rnw:630-631 (eval = FALSE)
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
-plot(split(lansing))
+## plot(split(lansing))
 
 
 ###################################################
-### code chunk number 42: datasets.Rnw:609-610
+### code chunk number 44: datasets.Rnw:638-639
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(longleaf)
 
 
 ###################################################
-### code chunk number 43: datasets.Rnw:619-621
+### code chunk number 45: datasets.Rnw:648-650
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(mucosa, chars=c(1,3), cols=c("red", "green"))
@@ -340,7 +350,7 @@ plot(mucosa.subwin, add=TRUE, lty=3)
 
 
 ###################################################
-### code chunk number 44: datasets.Rnw:635-638
+### code chunk number 46: datasets.Rnw:666-669
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(murchison$greenstone, main="Murchison data", col="lightgreen")
@@ -349,21 +359,35 @@ plot(murchison$faults, add=TRUE, col="red")
 
 
 ###################################################
-### code chunk number 45: datasets.Rnw:646-647
+### code chunk number 47: datasets.Rnw:675-676
+###################################################
+reedy <- owin(c(580, 650), c(6986, 7026))
+
+
+###################################################
+### code chunk number 48: datasets.Rnw:681-684
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+plot(murchison$greenstone[reedy], main="Murchison data", col="lightgreen")
+plot(murchison$gold[reedy], add=TRUE, pch=3, col="blue")
+plot(murchison$faults[reedy], add=TRUE, col="red")
+
+
+###################################################
+### code chunk number 49: datasets.Rnw:692-693
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(nbfires, use.marks=FALSE, pch=".")
 
 
 ###################################################
-### code chunk number 46: datasets.Rnw:650-651
+### code chunk number 50: datasets.Rnw:699-700 (eval = FALSE)
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
-plot(split(nbfires), use.marks=FALSE, chars=".")
+## plot(split(nbfires), use.marks=FALSE, chars=".")
 
 
 ###################################################
-### code chunk number 47: datasets.Rnw:654-659
+### code chunk number 51: datasets.Rnw:703-708
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 par(mar=c(0,0,2,0))
@@ -374,7 +398,7 @@ plot(split(nbfires)$"2000", which.marks="fire.type",
 
 
 ###################################################
-### code chunk number 48: datasets.Rnw:667-669
+### code chunk number 52: datasets.Rnw:716-718
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(nztrees)
@@ -382,43 +406,48 @@ plot(trim.rectangle(as.owin(nztrees), c(0,5), 0), add=TRUE, lty=3)
 
 
 ###################################################
-### code chunk number 49: datasets.Rnw:682-683
+### code chunk number 53: datasets.Rnw:731-732
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot(osteo[1:10,], main.panel="", pch=21, bg='white')
+plot(osteo[1:4,], main.panel="", pch=21, bg='white')
 
 
 ###################################################
-### code chunk number 50: datasets.Rnw:689-690 (eval = FALSE)
+### code chunk number 54: datasets.Rnw:738-739 (eval = FALSE)
 ###################################################
 ## system.file("rawdata/osteo/osteo36.txt", package="spatstat")
 
 
 ###################################################
-### code chunk number 51: datasets.Rnw:699-700
+### code chunk number 55: datasets.Rnw:748-749
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(paracou, cols=2:3, chars=c(16,3))
 
 
 ###################################################
-### code chunk number 52: datasets.Rnw:708-709
+### code chunk number 56: datasets.Rnw:757-758
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 ponderosa.extra$plotit()
 
 
 ###################################################
-### code chunk number 53: datasets.Rnw:720-723
+### code chunk number 57: datasets.Rnw:770-771
+###################################################
+pyr <- pyramidal[c(FALSE,TRUE), ]
+
+
+###################################################
+### code chunk number 58: datasets.Rnw:774-776
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-pyr <- pyramidal
-pyr$grp <- abbreviate(pyramidal$group, minlength=7)
+pyr$grp <- abbreviate(pyr$group, minlength=7)
 plot(pyr, quote(plot(Neurons, pch=16, main=grp)), main="Pyramidal Neurons")
 
 
 ###################################################
-### code chunk number 54: datasets.Rnw:743-745
+### code chunk number 59: datasets.Rnw:796-798
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(redwood)
@@ -426,43 +455,43 @@ plot(redwood3, add=TRUE, pch=20)
 
 
 ###################################################
-### code chunk number 55: datasets.Rnw:748-749
+### code chunk number 60: datasets.Rnw:801-802
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 redwoodfull.extra$plotit()
 
 
 ###################################################
-### code chunk number 56: datasets.Rnw:763-765
+### code chunk number 61: datasets.Rnw:816-818
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot(as.listof(residualspaper[c("Fig1", "Fig4a", "Fig4b", "Fig4c")]), 
+plot(as.solist(residualspaper[c("Fig1", "Fig4a", "Fig4b", "Fig4c")]), 
      main="")
 
 
 ###################################################
-### code chunk number 57: datasets.Rnw:773-774
+### code chunk number 62: datasets.Rnw:826-827
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 shapley.extra$plotit(main="Shapley")
 
 
 ###################################################
-### code chunk number 58: datasets.Rnw:781-782
+### code chunk number 63: datasets.Rnw:834-835
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(simdat)
 
 
 ###################################################
-### code chunk number 59: datasets.Rnw:790-791
+### code chunk number 64: datasets.Rnw:843-844
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(spiders, pch=16, show.window=FALSE)
 
 
 ###################################################
-### code chunk number 60: datasets.Rnw:798-801
+### code chunk number 65: datasets.Rnw:851-854
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(sporophores, chars=c(16,1,2), cex=0.6)
@@ -471,28 +500,28 @@ text(15,8,"Tree", cex=0.75)
 
 
 ###################################################
-### code chunk number 61: datasets.Rnw:810-811
+### code chunk number 66: datasets.Rnw:863-864
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(spruces, maxsize=min(nndist(spruces)))
 
 
 ###################################################
-### code chunk number 62: datasets.Rnw:820-821
+### code chunk number 67: datasets.Rnw:873-874
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(swedishpines)
 
 
 ###################################################
-### code chunk number 63: datasets.Rnw:830-831
+### code chunk number 68: datasets.Rnw:883-884
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(urkiola, cex=0.5, cols=2:3)
 
 
 ###################################################
-### code chunk number 64: datasets.Rnw:838-840
+### code chunk number 69: datasets.Rnw:891-893
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 par(mar=c(0,0,2,0))
@@ -500,7 +529,7 @@ plot(waka, markscale=0.04, main=c("Waka national park", "tree diameters"))
 
 
 ###################################################
-### code chunk number 65: datasets.Rnw:847-851
+### code chunk number 70: datasets.Rnw:900-904
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 v <- rotate(vesicles, pi/2)
@@ -510,13 +539,13 @@ plot(ve$activezone, add=TRUE, lwd=3)
 
 
 ###################################################
-### code chunk number 66: datasets.Rnw:876-877 (eval = FALSE)
+### code chunk number 71: datasets.Rnw:929-930 (eval = FALSE)
 ###################################################
 ## system.file("rawdata/vesicles/mitochondria.txt", package="spatstat")
 
 
 ###################################################
-### code chunk number 67: datasets.Rnw:885-886
+### code chunk number 72: datasets.Rnw:938-939
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(waterstriders)
